.. Scrapegraph-ai documentation master file, created by
   sphinx-quickstart on Wed Jan 31 15:38:23 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :maxdepth: 2
   :caption: Introduction

   introduction/overview
   introduction/contributing

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   getting_started/installation
   getting_started/examples

.. toctree::
   :maxdepth: 2
   :caption: Scrapers

   scrapers/graphs

.. toctree::
   :maxdepth: 2
   :caption: Modules

   modules/modules

.. toctree::
   :hidden:
   :caption: EXTERNAL RESOURCES

   GitHub <https://github.com/VinciGit00/Scrapegraph-ai>
   Discord <https://discord.gg/uJN7TYcpNa>
   Linkedin <https://www.linkedin.com/company/scrapegraphai/>
   Twitter <https://twitter.com/scrapegraphai>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`